from .code_speed_test import speed_test
from . import session
from .result import Result

